@@ -45,7 +45,7 @@ class TOCItem : public NavigatorItem
         const TOC *toc() const { return m_toc; }
 
     private:
-        TOC *m_toc;
+        TOC *m_toc = nullptr;
 };
 
 class TOCChapterItem : public TOCItem
@@ -75,8 +75,8 @@ class TOCSectionItem : public TOCItem
 bool TOC::m_alreadyWarned = false;
 
 TOC::TOC( NavigatorItem *parentItem )
+    : m_parentItem(parentItem)
 {
-    m_parentItem = parentItem;
 }
 
 void TOC::build( const QString &file )
@@ -237,9 +237,9 @@ void TOC::fillTree()
         for ( int sectCount = 0; sectCount < sections.count(); sectCount++ ) {
             QDomElement sectElem = sections.item( sectCount ).toElement();
             QDomElement sectTitleElem = childElement( sectElem, QStringLiteral( "title" ) );
-            QString sectTitle = sectTitleElem.text().simplified();
+            const QString sectTitle = sectTitleElem.text().simplified();
             QDomElement sectRefElem = childElement( sectElem, QStringLiteral( "anchor" ) );
-            QString sectRef = sectRefElem.text().trimmed();
+            const QString sectRef = sectRefElem.text().trimmed();
 
             sectItem = new TOCSectionItem( this, chapItem, sectItem, sectTitle, sectRef );
         }
@@ -259,7 +259,7 @@ void TOC::slotItemSelected( QTreeWidgetItem *item )
 {
     TOCItem *tocItem;
     if ( ( tocItem = dynamic_cast<TOCItem *>( item ) ) )
-        emit itemSelected( tocItem->entry()->url() );
+        Q_EMIT itemSelected( tocItem->entry()->url() );
 
     item->setExpanded( !item->isExpanded() );
 }
